@@ -27,11 +27,11 @@ PDF::Cropmarks - Add cropmarks to existing PDFs
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -442,7 +442,11 @@ sub add_cropmarks {
 
 sub _round {
     my ($self, $float) = @_;
-    $float || 0;
+    print "Rounding $float\n" if DEBUG;
+    return 0 unless $float;
+    if ($float < 0.001 && $float > -0.001) {
+        return 0;
+    }
     return sprintf('%.3f', $float);
 }
 
